Struct tonic_types::pb::RequestInfo
source · Expand description
Contains metadata about the request that clients can attach when filing a bug or providing other forms of feedback.
Fields
request_id: StringAn opaque string that should only be interpreted by the service generating it. For example, it can be used to identify requests in the service’s logs.
serving_data: StringAny data that was used to serve this request. For example, an encrypted stack trace that can be sent back to the service provider for debugging.