pub struct ResourceInfo {
    pub resource_type: String,
    pub resource_name: String,
    pub owner: String,
    pub description: String,
}
Describes the resource that is being accessed.

Fields

resource_type: String

A name for the type of resource being accessed, e.g. “sql table”, “cloud storage bucket”, “file”, “Google calendar”; or the type URL of the resource: e.g. “type.googleapis.com/google.pubsub.v1.Topic”.

resource_name: String

The name of the resource being accessed. For example, a shared calendar name: “example.com_4fghdhgsrgh@group.calendar.google.com”, if the current error is \[google.rpc.Code.PERMISSION_DENIED][google.rpc.Code.PERMISSION_DENIED\].

owner: String

The owner of the resource (optional). For example, “user:” or “project:”.

description: String

Describes what error is encountered when accessing this resource. For example, updating a cloud project may require the writer permission on the developer console project.