Struct tonic_types::pb::RetryInfo

source ·
pub struct RetryInfo {
    pub retry_delay: Option<Duration>,
}
Describes when the clients can retry a failed request. Clients could ignore the recommendation here or retry when this information is missing from error responses.

It’s always recommended that clients should use exponential backoff when retrying.

Clients should wait until retry_delay amount of time has passed since receiving the error response before retrying. If retrying requests also fail, clients should use an exponential backoff scheme to gradually increase the delay between retries based on retry_delay, until either a maximum number of retries have been reached or a maximum retry delay cap has been reached.

Fields

retry_delay: Option<Duration>

Clients should wait at least this long between retrying the same request.